@@ -2,7 +2,7 @@
 #'  \tabular{ll}{
 #'   **Package:** \tab tesselle \cr
 #'   **Type:** \tab Package \cr
-#'   **Version:** \tab 1.0.0 \cr
+#'   **Version:** \tab 1.1.0 \cr
 #'   **License:** \tab GPL-3 \cr
 #'  }
 #'
@@ -19,13 +19,24 @@
 #'  Nicolas Frerebeau\cr
 #'  \email{nicolas.frerebeau@@u-bordeaux-montaigne.fr}
 #'
-#'  IRAMAT-CRP2A (UMR 5060)\cr
+#'  Archéosciences Bordeaux (UMR 6034)\cr
 #'  Maison de l'Archéologie\cr
 #'  Université Bordeaux Montaigne\cr
-#'  F-33607 Pessac cedex\cr
+#'  33607 Pessac cedex\cr
 #'  France
 #' @name tesselle-package
 #' @aliases tesselle
 #' @docType package
 #' @keywords internal
 "_PACKAGE"
+
+# Suppress R CMD check note
+# ("All declared Imports should be used.")
+unused <- function() {
+  arkhe::is_empty
+  dimensio::ca
+  folio::arnold1949
+  kairos::mcd
+  khroma::colour
+  tabula::heterogeneity
+}
